Documentation
¶
Overview ¶
Code generated by ogen, DO NOT EDIT.
Index ¶
- func WithServerURL(ctx context.Context, u *url.URL) context.Context
- type Account
- func (s *Account) Decode(d *jx.Decoder) error
- func (s *Account) Encode(e *jx.Encoder)
- func (s *Account) GetAccountDetails() AccountAccountDetails
- func (s *Account) GetCurrency() Currency
- func (s *Account) GetCustomerAccountId() OptString
- func (s *Account) GetCustomerId() uuid.UUID
- func (s *Account) GetID() uuid.UUID
- func (s *Account) GetInstitutionId() OptString
- func (s *Account) GetInstitutionName() OptString
- func (s *Account) MarshalJSON() ([]byte, error)
- func (s *Account) SetAccountDetails(val AccountAccountDetails)
- func (s *Account) SetCurrency(val Currency)
- func (s *Account) SetCustomerAccountId(val OptString)
- func (s *Account) SetCustomerId(val uuid.UUID)
- func (s *Account) SetID(val uuid.UUID)
- func (s *Account) SetInstitutionId(val OptString)
- func (s *Account) SetInstitutionName(val OptString)
- func (s *Account) UnmarshalJSON(data []byte) error
- func (s *Account) Validate() error
- type AccountAccountDetails
- func (s *AccountAccountDetails) Decode(d *jx.Decoder) error
- func (s *AccountAccountDetails) Encode(e *jx.Encoder)
- func (s *AccountAccountDetails) GetOneOf() AccountAccountDetailsSum
- func (s *AccountAccountDetails) MarshalJSON() ([]byte, error)
- func (s *AccountAccountDetails) SetOneOf(val AccountAccountDetailsSum)
- func (s *AccountAccountDetails) UnmarshalJSON(data []byte) error
- func (s *AccountAccountDetails) Validate() error
- type AccountAccountDetailsSum
- func (s *AccountAccountDetailsSum) Decode(d *jx.Decoder) error
- func (s AccountAccountDetailsSum) Encode(e *jx.Encoder)
- func (s AccountAccountDetailsSum) GetCvuAccountDetails() (v CvuAccountDetails, ok bool)
- func (s AccountAccountDetailsSum) GetDinopayAccountDetails() (v DinopayAccountDetails, ok bool)
- func (s AccountAccountDetailsSum) IsCvuAccountDetails() bool
- func (s AccountAccountDetailsSum) IsDinopayAccountDetails() bool
- func (s AccountAccountDetailsSum) MarshalJSON() ([]byte, error)
- func (s *AccountAccountDetailsSum) SetCvuAccountDetails(v CvuAccountDetails)
- func (s *AccountAccountDetailsSum) SetDinopayAccountDetails(v DinopayAccountDetails)
- func (s *AccountAccountDetailsSum) UnmarshalJSON(data []byte) error
- func (s AccountAccountDetailsSum) Validate() error
- type AccountAccountDetailsSumType
- type AliasCvuRoutingInfo
- func (s *AliasCvuRoutingInfo) Decode(d *jx.Decoder) error
- func (s *AliasCvuRoutingInfo) Encode(e *jx.Encoder)
- func (s *AliasCvuRoutingInfo) GetAlias() string
- func (s *AliasCvuRoutingInfo) GetCvuRoutingInfoType() string
- func (s *AliasCvuRoutingInfo) MarshalJSON() ([]byte, error)
- func (s *AliasCvuRoutingInfo) SetAlias(val string)
- func (s *AliasCvuRoutingInfo) SetCvuRoutingInfoType(val string)
- func (s *AliasCvuRoutingInfo) UnmarshalJSON(data []byte) error
- func (s *AliasCvuRoutingInfo) Validate() error
- type Client
- type ClientOption
- type Currency
- func (Currency) AllValues() []Currency
- func (s *Currency) Decode(d *jx.Decoder) error
- func (s Currency) Encode(e *jx.Encoder)
- func (s Currency) MarshalJSON() ([]byte, error)
- func (s Currency) MarshalText() ([]byte, error)
- func (s *Currency) UnmarshalJSON(data []byte) error
- func (s *Currency) UnmarshalText(data []byte) error
- func (s Currency) Validate() error
- type CvuAccountDetails
- func (s *CvuAccountDetails) Decode(d *jx.Decoder) error
- func (s *CvuAccountDetails) Encode(e *jx.Encoder)
- func (s *CvuAccountDetails) GetAccountType() string
- func (s *CvuAccountDetails) GetCuit() OptString
- func (s *CvuAccountDetails) GetRoutingInfo() CvuAccountDetailsRoutingInfo
- func (s *CvuAccountDetails) MarshalJSON() ([]byte, error)
- func (s *CvuAccountDetails) SetAccountType(val string)
- func (s *CvuAccountDetails) SetCuit(val OptString)
- func (s *CvuAccountDetails) SetRoutingInfo(val CvuAccountDetailsRoutingInfo)
- func (s *CvuAccountDetails) UnmarshalJSON(data []byte) error
- func (s *CvuAccountDetails) Validate() error
- type CvuAccountDetailsRoutingInfo
- func (s *CvuAccountDetailsRoutingInfo) Decode(d *jx.Decoder) error
- func (s *CvuAccountDetailsRoutingInfo) Encode(e *jx.Encoder)
- func (s *CvuAccountDetailsRoutingInfo) GetOneOf() CvuAccountDetailsRoutingInfoSum
- func (s *CvuAccountDetailsRoutingInfo) MarshalJSON() ([]byte, error)
- func (s *CvuAccountDetailsRoutingInfo) SetOneOf(val CvuAccountDetailsRoutingInfoSum)
- func (s *CvuAccountDetailsRoutingInfo) UnmarshalJSON(data []byte) error
- func (s *CvuAccountDetailsRoutingInfo) Validate() error
- type CvuAccountDetailsRoutingInfoSum
- func (s *CvuAccountDetailsRoutingInfoSum) Decode(d *jx.Decoder) error
- func (s CvuAccountDetailsRoutingInfoSum) Encode(e *jx.Encoder)
- func (s CvuAccountDetailsRoutingInfoSum) GetAliasCvuRoutingInfo() (v AliasCvuRoutingInfo, ok bool)
- func (s CvuAccountDetailsRoutingInfoSum) GetCvuCvuRoutingInfo() (v CvuCvuRoutingInfo, ok bool)
- func (s CvuAccountDetailsRoutingInfoSum) IsAliasCvuRoutingInfo() bool
- func (s CvuAccountDetailsRoutingInfoSum) IsCvuCvuRoutingInfo() bool
- func (s CvuAccountDetailsRoutingInfoSum) MarshalJSON() ([]byte, error)
- func (s *CvuAccountDetailsRoutingInfoSum) SetAliasCvuRoutingInfo(v AliasCvuRoutingInfo)
- func (s *CvuAccountDetailsRoutingInfoSum) SetCvuCvuRoutingInfo(v CvuCvuRoutingInfo)
- func (s *CvuAccountDetailsRoutingInfoSum) UnmarshalJSON(data []byte) error
- func (s CvuAccountDetailsRoutingInfoSum) Validate() error
- type CvuAccountDetailsRoutingInfoSumType
- type CvuCvuRoutingInfo
- func (s *CvuCvuRoutingInfo) Decode(d *jx.Decoder) error
- func (s *CvuCvuRoutingInfo) Encode(e *jx.Encoder)
- func (s *CvuCvuRoutingInfo) GetCvu() string
- func (s *CvuCvuRoutingInfo) GetCvuRoutingInfoType() string
- func (s *CvuCvuRoutingInfo) MarshalJSON() ([]byte, error)
- func (s *CvuCvuRoutingInfo) SetCvu(val string)
- func (s *CvuCvuRoutingInfo) SetCvuRoutingInfoType(val string)
- func (s *CvuCvuRoutingInfo) UnmarshalJSON(data []byte) error
- func (s *CvuCvuRoutingInfo) Validate() error
- type DinopayAccountDetails
- func (s *DinopayAccountDetails) Decode(d *jx.Decoder) error
- func (s *DinopayAccountDetails) Encode(e *jx.Encoder)
- func (s *DinopayAccountDetails) GetAccountHolder() string
- func (s *DinopayAccountDetails) GetAccountNumber() string
- func (s *DinopayAccountDetails) GetAccountType() string
- func (s *DinopayAccountDetails) MarshalJSON() ([]byte, error)
- func (s *DinopayAccountDetails) SetAccountHolder(val string)
- func (s *DinopayAccountDetails) SetAccountNumber(val string)
- func (s *DinopayAccountDetails) SetAccountType(val string)
- func (s *DinopayAccountDetails) UnmarshalJSON(data []byte) error
- type ErrorHandler
- type Handler
- type Invoker
- type Labeler
- type ListAccountsNotFound
- type ListAccountsOKApplicationJSON
- func (s *ListAccountsOKApplicationJSON) Decode(d *jx.Decoder) error
- func (s ListAccountsOKApplicationJSON) Encode(e *jx.Encoder)
- func (s ListAccountsOKApplicationJSON) MarshalJSON() ([]byte, error)
- func (s *ListAccountsOKApplicationJSON) UnmarshalJSON(data []byte) error
- func (s ListAccountsOKApplicationJSON) Validate() error
- type ListAccountsParams
- type ListAccountsRes
- type Middleware
- type OperationName
- type OptInt
- type OptString
- func (o *OptString) Decode(d *jx.Decoder) error
- func (o OptString) Encode(e *jx.Encoder)
- func (o OptString) Get() (v string, ok bool)
- func (o OptString) IsSet() bool
- func (s OptString) MarshalJSON() ([]byte, error)
- func (o OptString) Or(d string) string
- func (o *OptString) Reset()
- func (o *OptString) SetTo(v string)
- func (s *OptString) UnmarshalJSON(data []byte) error
- type OptUUID
- type Option
- type Route
- type Server
- type ServerOption
- func WithErrorHandler(h ErrorHandler) ServerOption
- func WithMaxMultipartMemory(max int64) ServerOption
- func WithMethodNotAllowed(methodNotAllowed func(w http.ResponseWriter, r *http.Request, allowed string)) ServerOption
- func WithMiddleware(m ...Middleware) ServerOption
- func WithNotFound(notFound http.HandlerFunc) ServerOption
- func WithPathPrefix(prefix string) ServerOption
- type UnimplementedHandler
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Account ¶
type Account struct {
// Walletera account unique identifier.
ID uuid.UUID `json:"id"`
// Walletera unique identifier of the customer (institution) that owns the account.
CustomerId uuid.UUID `json:"customerId"`
// Identifier assigned to the account by the customer.
CustomerAccountId OptString `json:"customerAccountId"`
InstitutionName OptString `json:"institutionName"`
InstitutionId OptString `json:"institutionId"`
Currency Currency `json:"currency"`
// Extra account details. The details depend on the accountType.
AccountDetails AccountAccountDetails `json:"accountDetails"`
}
Merged schema. Ref: #/components/schemas/account
func (*Account) GetAccountDetails ¶
func (s *Account) GetAccountDetails() AccountAccountDetails
GetAccountDetails returns the value of AccountDetails.
func (*Account) GetCurrency ¶
GetCurrency returns the value of Currency.
func (*Account) GetCustomerAccountId ¶
GetCustomerAccountId returns the value of CustomerAccountId.
func (*Account) GetCustomerId ¶
GetCustomerId returns the value of CustomerId.
func (*Account) GetInstitutionId ¶
GetInstitutionId returns the value of InstitutionId.
func (*Account) GetInstitutionName ¶
GetInstitutionName returns the value of InstitutionName.
func (*Account) MarshalJSON ¶
MarshalJSON implements stdjson.Marshaler.
func (*Account) SetAccountDetails ¶
func (s *Account) SetAccountDetails(val AccountAccountDetails)
SetAccountDetails sets the value of AccountDetails.
func (*Account) SetCurrency ¶
SetCurrency sets the value of Currency.
func (*Account) SetCustomerAccountId ¶
SetCustomerAccountId sets the value of CustomerAccountId.
func (*Account) SetCustomerId ¶
SetCustomerId sets the value of CustomerId.
func (*Account) SetInstitutionId ¶
SetInstitutionId sets the value of InstitutionId.
func (*Account) SetInstitutionName ¶
SetInstitutionName sets the value of InstitutionName.
func (*Account) UnmarshalJSON ¶
UnmarshalJSON implements stdjson.Unmarshaler.
type AccountAccountDetails ¶
type AccountAccountDetails struct {
OneOf AccountAccountDetailsSum
}
Extra account details. The details depend on the accountType.
func (*AccountAccountDetails) Decode ¶
func (s *AccountAccountDetails) Decode(d *jx.Decoder) error
Decode decodes AccountAccountDetails from json.
func (*AccountAccountDetails) Encode ¶
func (s *AccountAccountDetails) Encode(e *jx.Encoder)
Encode implements json.Marshaler.
func (*AccountAccountDetails) GetOneOf ¶
func (s *AccountAccountDetails) GetOneOf() AccountAccountDetailsSum
GetOneOf returns the value of OneOf.
func (*AccountAccountDetails) MarshalJSON ¶
func (s *AccountAccountDetails) MarshalJSON() ([]byte, error)
MarshalJSON implements stdjson.Marshaler.
func (*AccountAccountDetails) SetOneOf ¶
func (s *AccountAccountDetails) SetOneOf(val AccountAccountDetailsSum)
SetOneOf sets the value of OneOf.
func (*AccountAccountDetails) UnmarshalJSON ¶
func (s *AccountAccountDetails) UnmarshalJSON(data []byte) error
UnmarshalJSON implements stdjson.Unmarshaler.
func (*AccountAccountDetails) Validate ¶
func (s *AccountAccountDetails) Validate() error
type AccountAccountDetailsSum ¶
type AccountAccountDetailsSum struct {
Type AccountAccountDetailsSumType // switch on this field
CvuAccountDetails CvuAccountDetails
DinopayAccountDetails DinopayAccountDetails
}
AccountAccountDetailsSum represents sum type.
func NewCvuAccountDetailsAccountAccountDetailsSum ¶
func NewCvuAccountDetailsAccountAccountDetailsSum(v CvuAccountDetails) AccountAccountDetailsSum
NewCvuAccountDetailsAccountAccountDetailsSum returns new AccountAccountDetailsSum from CvuAccountDetails.
func NewDinopayAccountDetailsAccountAccountDetailsSum ¶
func NewDinopayAccountDetailsAccountAccountDetailsSum(v DinopayAccountDetails) AccountAccountDetailsSum
NewDinopayAccountDetailsAccountAccountDetailsSum returns new AccountAccountDetailsSum from DinopayAccountDetails.
func (*AccountAccountDetailsSum) Decode ¶
func (s *AccountAccountDetailsSum) Decode(d *jx.Decoder) error
Decode decodes AccountAccountDetailsSum from json.
func (AccountAccountDetailsSum) Encode ¶
func (s AccountAccountDetailsSum) Encode(e *jx.Encoder)
Encode encodes AccountAccountDetailsSum as json.
func (AccountAccountDetailsSum) GetCvuAccountDetails ¶
func (s AccountAccountDetailsSum) GetCvuAccountDetails() (v CvuAccountDetails, ok bool)
GetCvuAccountDetails returns CvuAccountDetails and true boolean if AccountAccountDetailsSum is CvuAccountDetails.
func (AccountAccountDetailsSum) GetDinopayAccountDetails ¶
func (s AccountAccountDetailsSum) GetDinopayAccountDetails() (v DinopayAccountDetails, ok bool)
GetDinopayAccountDetails returns DinopayAccountDetails and true boolean if AccountAccountDetailsSum is DinopayAccountDetails.
func (AccountAccountDetailsSum) IsCvuAccountDetails ¶
func (s AccountAccountDetailsSum) IsCvuAccountDetails() bool
IsCvuAccountDetails reports whether AccountAccountDetailsSum is CvuAccountDetails.
func (AccountAccountDetailsSum) IsDinopayAccountDetails ¶
func (s AccountAccountDetailsSum) IsDinopayAccountDetails() bool
IsDinopayAccountDetails reports whether AccountAccountDetailsSum is DinopayAccountDetails.
func (AccountAccountDetailsSum) MarshalJSON ¶
func (s AccountAccountDetailsSum) MarshalJSON() ([]byte, error)
MarshalJSON implements stdjson.Marshaler.
func (*AccountAccountDetailsSum) SetCvuAccountDetails ¶
func (s *AccountAccountDetailsSum) SetCvuAccountDetails(v CvuAccountDetails)
SetCvuAccountDetails sets AccountAccountDetailsSum to CvuAccountDetails.
func (*AccountAccountDetailsSum) SetDinopayAccountDetails ¶
func (s *AccountAccountDetailsSum) SetDinopayAccountDetails(v DinopayAccountDetails)
SetDinopayAccountDetails sets AccountAccountDetailsSum to DinopayAccountDetails.
func (*AccountAccountDetailsSum) UnmarshalJSON ¶
func (s *AccountAccountDetailsSum) UnmarshalJSON(data []byte) error
UnmarshalJSON implements stdjson.Unmarshaler.
func (AccountAccountDetailsSum) Validate ¶
func (s AccountAccountDetailsSum) Validate() error
type AccountAccountDetailsSumType ¶
type AccountAccountDetailsSumType string
AccountAccountDetailsSumType is oneOf type of AccountAccountDetailsSum.
const ( CvuAccountDetailsAccountAccountDetailsSum AccountAccountDetailsSumType = "cvu" DinopayAccountDetailsAccountAccountDetailsSum AccountAccountDetailsSumType = "dinopay" )
Possible values for AccountAccountDetailsSumType.
type AliasCvuRoutingInfo ¶
type AliasCvuRoutingInfo struct {
CvuRoutingInfoType string `json:"cvuRoutingInfoType"`
Alias string `json:"alias"`
}
Ref: #/components/schemas/aliasCvuRoutingInfo
func (*AliasCvuRoutingInfo) Decode ¶
func (s *AliasCvuRoutingInfo) Decode(d *jx.Decoder) error
Decode decodes AliasCvuRoutingInfo from json.
func (*AliasCvuRoutingInfo) Encode ¶
func (s *AliasCvuRoutingInfo) Encode(e *jx.Encoder)
Encode implements json.Marshaler.
func (*AliasCvuRoutingInfo) GetAlias ¶
func (s *AliasCvuRoutingInfo) GetAlias() string
GetAlias returns the value of Alias.
func (*AliasCvuRoutingInfo) GetCvuRoutingInfoType ¶
func (s *AliasCvuRoutingInfo) GetCvuRoutingInfoType() string
GetCvuRoutingInfoType returns the value of CvuRoutingInfoType.
func (*AliasCvuRoutingInfo) MarshalJSON ¶
func (s *AliasCvuRoutingInfo) MarshalJSON() ([]byte, error)
MarshalJSON implements stdjson.Marshaler.
func (*AliasCvuRoutingInfo) SetAlias ¶
func (s *AliasCvuRoutingInfo) SetAlias(val string)
SetAlias sets the value of Alias.
func (*AliasCvuRoutingInfo) SetCvuRoutingInfoType ¶
func (s *AliasCvuRoutingInfo) SetCvuRoutingInfoType(val string)
SetCvuRoutingInfoType sets the value of CvuRoutingInfoType.
func (*AliasCvuRoutingInfo) UnmarshalJSON ¶
func (s *AliasCvuRoutingInfo) UnmarshalJSON(data []byte) error
UnmarshalJSON implements stdjson.Unmarshaler.
func (*AliasCvuRoutingInfo) Validate ¶
func (s *AliasCvuRoutingInfo) Validate() error
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client implements OAS client.
func NewClient ¶
func NewClient(serverURL string, opts ...ClientOption) (*Client, error)
NewClient initializes new Client defined by OAS.
func (*Client) ListAccounts ¶
func (c *Client) ListAccounts(ctx context.Context, params ListAccountsParams) (ListAccountsRes, error)
ListAccounts invokes listAccounts operation.
Allows to retrieve a list of accounts based on search parameters.
GET /accounts
type ClientOption ¶
type ClientOption interface {
// contains filtered or unexported methods
}
ClientOption is client config option.
func WithClient ¶
func WithClient(client ht.Client) ClientOption
WithClient specifies http client to use.
type Currency ¶
type Currency string
Ref: #/components/schemas/currency
func (Currency) MarshalJSON ¶
MarshalJSON implements stdjson.Marshaler.
func (Currency) MarshalText ¶
MarshalText implements encoding.TextMarshaler.
func (*Currency) UnmarshalJSON ¶
UnmarshalJSON implements stdjson.Unmarshaler.
func (*Currency) UnmarshalText ¶
UnmarshalText implements encoding.TextUnmarshaler.
type CvuAccountDetails ¶
type CvuAccountDetails struct {
AccountType string `json:"accountType"`
// Account owner national identification number.
Cuit OptString `json:"cuit"`
RoutingInfo CvuAccountDetailsRoutingInfo `json:"routingInfo"`
}
Ref: #/components/schemas/cvuAccountDetails
func (*CvuAccountDetails) Decode ¶
func (s *CvuAccountDetails) Decode(d *jx.Decoder) error
Decode decodes CvuAccountDetails from json.
func (*CvuAccountDetails) Encode ¶
func (s *CvuAccountDetails) Encode(e *jx.Encoder)
Encode implements json.Marshaler.
func (*CvuAccountDetails) GetAccountType ¶
func (s *CvuAccountDetails) GetAccountType() string
GetAccountType returns the value of AccountType.
func (*CvuAccountDetails) GetCuit ¶
func (s *CvuAccountDetails) GetCuit() OptString
GetCuit returns the value of Cuit.
func (*CvuAccountDetails) GetRoutingInfo ¶
func (s *CvuAccountDetails) GetRoutingInfo() CvuAccountDetailsRoutingInfo
GetRoutingInfo returns the value of RoutingInfo.
func (*CvuAccountDetails) MarshalJSON ¶
func (s *CvuAccountDetails) MarshalJSON() ([]byte, error)
MarshalJSON implements stdjson.Marshaler.
func (*CvuAccountDetails) SetAccountType ¶
func (s *CvuAccountDetails) SetAccountType(val string)
SetAccountType sets the value of AccountType.
func (*CvuAccountDetails) SetCuit ¶
func (s *CvuAccountDetails) SetCuit(val OptString)
SetCuit sets the value of Cuit.
func (*CvuAccountDetails) SetRoutingInfo ¶
func (s *CvuAccountDetails) SetRoutingInfo(val CvuAccountDetailsRoutingInfo)
SetRoutingInfo sets the value of RoutingInfo.
func (*CvuAccountDetails) UnmarshalJSON ¶
func (s *CvuAccountDetails) UnmarshalJSON(data []byte) error
UnmarshalJSON implements stdjson.Unmarshaler.
func (*CvuAccountDetails) Validate ¶
func (s *CvuAccountDetails) Validate() error
type CvuAccountDetailsRoutingInfo ¶
type CvuAccountDetailsRoutingInfo struct {
OneOf CvuAccountDetailsRoutingInfoSum
}
func (*CvuAccountDetailsRoutingInfo) Decode ¶
func (s *CvuAccountDetailsRoutingInfo) Decode(d *jx.Decoder) error
Decode decodes CvuAccountDetailsRoutingInfo from json.
func (*CvuAccountDetailsRoutingInfo) Encode ¶
func (s *CvuAccountDetailsRoutingInfo) Encode(e *jx.Encoder)
Encode implements json.Marshaler.
func (*CvuAccountDetailsRoutingInfo) GetOneOf ¶
func (s *CvuAccountDetailsRoutingInfo) GetOneOf() CvuAccountDetailsRoutingInfoSum
GetOneOf returns the value of OneOf.
func (*CvuAccountDetailsRoutingInfo) MarshalJSON ¶
func (s *CvuAccountDetailsRoutingInfo) MarshalJSON() ([]byte, error)
MarshalJSON implements stdjson.Marshaler.
func (*CvuAccountDetailsRoutingInfo) SetOneOf ¶
func (s *CvuAccountDetailsRoutingInfo) SetOneOf(val CvuAccountDetailsRoutingInfoSum)
SetOneOf sets the value of OneOf.
func (*CvuAccountDetailsRoutingInfo) UnmarshalJSON ¶
func (s *CvuAccountDetailsRoutingInfo) UnmarshalJSON(data []byte) error
UnmarshalJSON implements stdjson.Unmarshaler.
func (*CvuAccountDetailsRoutingInfo) Validate ¶
func (s *CvuAccountDetailsRoutingInfo) Validate() error
type CvuAccountDetailsRoutingInfoSum ¶
type CvuAccountDetailsRoutingInfoSum struct {
Type CvuAccountDetailsRoutingInfoSumType // switch on this field
CvuCvuRoutingInfo CvuCvuRoutingInfo
AliasCvuRoutingInfo AliasCvuRoutingInfo
}
CvuAccountDetailsRoutingInfoSum represents sum type.
func NewAliasCvuRoutingInfoCvuAccountDetailsRoutingInfoSum ¶
func NewAliasCvuRoutingInfoCvuAccountDetailsRoutingInfoSum(v AliasCvuRoutingInfo) CvuAccountDetailsRoutingInfoSum
NewAliasCvuRoutingInfoCvuAccountDetailsRoutingInfoSum returns new CvuAccountDetailsRoutingInfoSum from AliasCvuRoutingInfo.
func NewCvuCvuRoutingInfoCvuAccountDetailsRoutingInfoSum ¶
func NewCvuCvuRoutingInfoCvuAccountDetailsRoutingInfoSum(v CvuCvuRoutingInfo) CvuAccountDetailsRoutingInfoSum
NewCvuCvuRoutingInfoCvuAccountDetailsRoutingInfoSum returns new CvuAccountDetailsRoutingInfoSum from CvuCvuRoutingInfo.
func (*CvuAccountDetailsRoutingInfoSum) Decode ¶
func (s *CvuAccountDetailsRoutingInfoSum) Decode(d *jx.Decoder) error
Decode decodes CvuAccountDetailsRoutingInfoSum from json.
func (CvuAccountDetailsRoutingInfoSum) Encode ¶
func (s CvuAccountDetailsRoutingInfoSum) Encode(e *jx.Encoder)
Encode encodes CvuAccountDetailsRoutingInfoSum as json.
func (CvuAccountDetailsRoutingInfoSum) GetAliasCvuRoutingInfo ¶
func (s CvuAccountDetailsRoutingInfoSum) GetAliasCvuRoutingInfo() (v AliasCvuRoutingInfo, ok bool)
GetAliasCvuRoutingInfo returns AliasCvuRoutingInfo and true boolean if CvuAccountDetailsRoutingInfoSum is AliasCvuRoutingInfo.
func (CvuAccountDetailsRoutingInfoSum) GetCvuCvuRoutingInfo ¶
func (s CvuAccountDetailsRoutingInfoSum) GetCvuCvuRoutingInfo() (v CvuCvuRoutingInfo, ok bool)
GetCvuCvuRoutingInfo returns CvuCvuRoutingInfo and true boolean if CvuAccountDetailsRoutingInfoSum is CvuCvuRoutingInfo.
func (CvuAccountDetailsRoutingInfoSum) IsAliasCvuRoutingInfo ¶
func (s CvuAccountDetailsRoutingInfoSum) IsAliasCvuRoutingInfo() bool
IsAliasCvuRoutingInfo reports whether CvuAccountDetailsRoutingInfoSum is AliasCvuRoutingInfo.
func (CvuAccountDetailsRoutingInfoSum) IsCvuCvuRoutingInfo ¶
func (s CvuAccountDetailsRoutingInfoSum) IsCvuCvuRoutingInfo() bool
IsCvuCvuRoutingInfo reports whether CvuAccountDetailsRoutingInfoSum is CvuCvuRoutingInfo.
func (CvuAccountDetailsRoutingInfoSum) MarshalJSON ¶
func (s CvuAccountDetailsRoutingInfoSum) MarshalJSON() ([]byte, error)
MarshalJSON implements stdjson.Marshaler.
func (*CvuAccountDetailsRoutingInfoSum) SetAliasCvuRoutingInfo ¶
func (s *CvuAccountDetailsRoutingInfoSum) SetAliasCvuRoutingInfo(v AliasCvuRoutingInfo)
SetAliasCvuRoutingInfo sets CvuAccountDetailsRoutingInfoSum to AliasCvuRoutingInfo.
func (*CvuAccountDetailsRoutingInfoSum) SetCvuCvuRoutingInfo ¶
func (s *CvuAccountDetailsRoutingInfoSum) SetCvuCvuRoutingInfo(v CvuCvuRoutingInfo)
SetCvuCvuRoutingInfo sets CvuAccountDetailsRoutingInfoSum to CvuCvuRoutingInfo.
func (*CvuAccountDetailsRoutingInfoSum) UnmarshalJSON ¶
func (s *CvuAccountDetailsRoutingInfoSum) UnmarshalJSON(data []byte) error
UnmarshalJSON implements stdjson.Unmarshaler.
func (CvuAccountDetailsRoutingInfoSum) Validate ¶
func (s CvuAccountDetailsRoutingInfoSum) Validate() error
type CvuAccountDetailsRoutingInfoSumType ¶
type CvuAccountDetailsRoutingInfoSumType string
CvuAccountDetailsRoutingInfoSumType is oneOf type of CvuAccountDetailsRoutingInfoSum.
const ( CvuCvuRoutingInfoCvuAccountDetailsRoutingInfoSum CvuAccountDetailsRoutingInfoSumType = "cvu" AliasCvuRoutingInfoCvuAccountDetailsRoutingInfoSum CvuAccountDetailsRoutingInfoSumType = "alias" )
Possible values for CvuAccountDetailsRoutingInfoSumType.
type CvuCvuRoutingInfo ¶
type CvuCvuRoutingInfo struct {
CvuRoutingInfoType string `json:"cvuRoutingInfoType"`
Cvu string `json:"cvu"`
}
Ref: #/components/schemas/cvuCvuRoutingInfo
func (*CvuCvuRoutingInfo) Decode ¶
func (s *CvuCvuRoutingInfo) Decode(d *jx.Decoder) error
Decode decodes CvuCvuRoutingInfo from json.
func (*CvuCvuRoutingInfo) Encode ¶
func (s *CvuCvuRoutingInfo) Encode(e *jx.Encoder)
Encode implements json.Marshaler.
func (*CvuCvuRoutingInfo) GetCvu ¶
func (s *CvuCvuRoutingInfo) GetCvu() string
GetCvu returns the value of Cvu.
func (*CvuCvuRoutingInfo) GetCvuRoutingInfoType ¶
func (s *CvuCvuRoutingInfo) GetCvuRoutingInfoType() string
GetCvuRoutingInfoType returns the value of CvuRoutingInfoType.
func (*CvuCvuRoutingInfo) MarshalJSON ¶
func (s *CvuCvuRoutingInfo) MarshalJSON() ([]byte, error)
MarshalJSON implements stdjson.Marshaler.
func (*CvuCvuRoutingInfo) SetCvu ¶
func (s *CvuCvuRoutingInfo) SetCvu(val string)
SetCvu sets the value of Cvu.
func (*CvuCvuRoutingInfo) SetCvuRoutingInfoType ¶
func (s *CvuCvuRoutingInfo) SetCvuRoutingInfoType(val string)
SetCvuRoutingInfoType sets the value of CvuRoutingInfoType.
func (*CvuCvuRoutingInfo) UnmarshalJSON ¶
func (s *CvuCvuRoutingInfo) UnmarshalJSON(data []byte) error
UnmarshalJSON implements stdjson.Unmarshaler.
func (*CvuCvuRoutingInfo) Validate ¶
func (s *CvuCvuRoutingInfo) Validate() error
type DinopayAccountDetails ¶
type DinopayAccountDetails struct {
AccountType string `json:"accountType"`
// Name of the owner of the account.
AccountHolder string `json:"accountHolder"`
// Account number on DinoPay.
AccountNumber string `json:"accountNumber"`
}
Ref: #/components/schemas/dinopayAccountDetails
func (*DinopayAccountDetails) Decode ¶
func (s *DinopayAccountDetails) Decode(d *jx.Decoder) error
Decode decodes DinopayAccountDetails from json.
func (*DinopayAccountDetails) Encode ¶
func (s *DinopayAccountDetails) Encode(e *jx.Encoder)
Encode implements json.Marshaler.
func (*DinopayAccountDetails) GetAccountHolder ¶
func (s *DinopayAccountDetails) GetAccountHolder() string
GetAccountHolder returns the value of AccountHolder.
func (*DinopayAccountDetails) GetAccountNumber ¶
func (s *DinopayAccountDetails) GetAccountNumber() string
GetAccountNumber returns the value of AccountNumber.
func (*DinopayAccountDetails) GetAccountType ¶
func (s *DinopayAccountDetails) GetAccountType() string
GetAccountType returns the value of AccountType.
func (*DinopayAccountDetails) MarshalJSON ¶
func (s *DinopayAccountDetails) MarshalJSON() ([]byte, error)
MarshalJSON implements stdjson.Marshaler.
func (*DinopayAccountDetails) SetAccountHolder ¶
func (s *DinopayAccountDetails) SetAccountHolder(val string)
SetAccountHolder sets the value of AccountHolder.
func (*DinopayAccountDetails) SetAccountNumber ¶
func (s *DinopayAccountDetails) SetAccountNumber(val string)
SetAccountNumber sets the value of AccountNumber.
func (*DinopayAccountDetails) SetAccountType ¶
func (s *DinopayAccountDetails) SetAccountType(val string)
SetAccountType sets the value of AccountType.
func (*DinopayAccountDetails) UnmarshalJSON ¶
func (s *DinopayAccountDetails) UnmarshalJSON(data []byte) error
UnmarshalJSON implements stdjson.Unmarshaler.
type Handler ¶
type Handler interface {
// ListAccounts implements listAccounts operation.
//
// Allows to retrieve a list of accounts based on search parameters.
//
// GET /accounts
ListAccounts(ctx context.Context, params ListAccountsParams) (ListAccountsRes, error)
}
Handler handles operations described by OpenAPI v3 specification.
type Invoker ¶
type Invoker interface {
// ListAccounts invokes listAccounts operation.
//
// Allows to retrieve a list of accounts based on search parameters.
//
// GET /accounts
ListAccounts(ctx context.Context, params ListAccountsParams) (ListAccountsRes, error)
}
Invoker invokes operations described by OpenAPI v3 specification.
type Labeler ¶
type Labeler struct {
// contains filtered or unexported fields
}
Labeler is used to allow adding custom attributes to the server request metrics.
func LabelerFromContext ¶
LabelerFromContext retrieves the Labeler from the provided context, if present.
If no Labeler was found in the provided context a new, empty Labeler is returned and the second return value is false. In this case it is safe to use the Labeler but any attributes added to it will not be used.
func (*Labeler) AttributeSet ¶
AttributeSet returns the attributes added to the Labeler as an attribute.Set.
type ListAccountsNotFound ¶
type ListAccountsNotFound struct{}
ListAccountsNotFound is response for ListAccounts operation.
type ListAccountsOKApplicationJSON ¶
type ListAccountsOKApplicationJSON []Account
func (*ListAccountsOKApplicationJSON) Decode ¶
func (s *ListAccountsOKApplicationJSON) Decode(d *jx.Decoder) error
Decode decodes ListAccountsOKApplicationJSON from json.
func (ListAccountsOKApplicationJSON) Encode ¶
func (s ListAccountsOKApplicationJSON) Encode(e *jx.Encoder)
Encode encodes ListAccountsOKApplicationJSON as json.
func (ListAccountsOKApplicationJSON) MarshalJSON ¶
func (s ListAccountsOKApplicationJSON) MarshalJSON() ([]byte, error)
MarshalJSON implements stdjson.Marshaler.
func (*ListAccountsOKApplicationJSON) UnmarshalJSON ¶
func (s *ListAccountsOKApplicationJSON) UnmarshalJSON(data []byte) error
UnmarshalJSON implements stdjson.Unmarshaler.
func (ListAccountsOKApplicationJSON) Validate ¶
func (s ListAccountsOKApplicationJSON) Validate() error
type ListAccountsParams ¶
type ListAccountsParams struct {
ID OptUUID `json:",omitempty,omitzero"`
// Customer Id.
CustomerId OptUUID `json:",omitempty,omitzero"`
Cvu OptString `json:",omitempty,omitzero"`
CvuAlias OptString `json:",omitempty,omitzero"`
DinoPayAccountNumber OptString `json:",omitempty,omitzero"`
// Number of accounts to return (for pagination).
Limit OptInt `json:",omitempty,omitzero"`
// Offset for pagination.
Offset OptInt `json:",omitempty,omitzero"`
}
ListAccountsParams is parameters of listAccounts operation.
type ListAccountsRes ¶
type ListAccountsRes interface {
// contains filtered or unexported methods
}
type OperationName ¶
type OperationName = string
OperationName is the ogen operation name
const (
ListAccountsOperation OperationName = "ListAccounts"
)
type OptInt ¶
OptInt is optional int.
type OptString ¶
OptString is optional string.
func NewOptString ¶
NewOptString returns new OptString with value set to v.
func (OptString) MarshalJSON ¶
MarshalJSON implements stdjson.Marshaler.
func (*OptString) UnmarshalJSON ¶
UnmarshalJSON implements stdjson.Unmarshaler.
type OptUUID ¶
OptUUID is optional uuid.UUID.
func NewOptUUID ¶
NewOptUUID returns new OptUUID with value set to v.
type Option ¶
type Option interface {
ServerOption
ClientOption
}
Option is config option.
func WithAttributes ¶
WithAttributes specifies default otel attributes.
func WithMeterProvider ¶
func WithMeterProvider(provider metric.MeterProvider) Option
WithMeterProvider specifies a meter provider to use for creating a meter.
If none is specified, the otel.GetMeterProvider() is used.
func WithTracerProvider ¶
func WithTracerProvider(provider trace.TracerProvider) Option
WithTracerProvider specifies a tracer provider to use for creating a tracer.
If none is specified, the global provider is used.
type Route ¶
type Route struct {
// contains filtered or unexported fields
}
Route is route object.
func (Route) OperationGroup ¶
OperationGroup returns the x-ogen-operation-group value.
func (Route) OperationID ¶
OperationID returns OpenAPI operationId.
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server implements http server based on OpenAPI v3 specification and calls Handler to handle requests.
func NewServer ¶
func NewServer(h Handler, opts ...ServerOption) (*Server, error)
NewServer creates new Server.
type ServerOption ¶
type ServerOption interface {
// contains filtered or unexported methods
}
ServerOption is server config option.
func WithErrorHandler ¶
func WithErrorHandler(h ErrorHandler) ServerOption
WithErrorHandler specifies error handler to use.
func WithMaxMultipartMemory ¶
func WithMaxMultipartMemory(max int64) ServerOption
WithMaxMultipartMemory specifies limit of memory for storing file parts. File parts which can't be stored in memory will be stored on disk in temporary files.
func WithMethodNotAllowed ¶
func WithMethodNotAllowed(methodNotAllowed func(w http.ResponseWriter, r *http.Request, allowed string)) ServerOption
WithMethodNotAllowed specifies Method Not Allowed handler to use.
func WithMiddleware ¶
func WithMiddleware(m ...Middleware) ServerOption
WithMiddleware specifies middlewares to use.
func WithNotFound ¶
func WithNotFound(notFound http.HandlerFunc) ServerOption
WithNotFound specifies Not Found handler to use.
func WithPathPrefix ¶
func WithPathPrefix(prefix string) ServerOption
WithPathPrefix specifies server path prefix.
type UnimplementedHandler ¶
type UnimplementedHandler struct{}
UnimplementedHandler is no-op Handler which returns http.ErrNotImplemented.
func (UnimplementedHandler) ListAccounts ¶
func (UnimplementedHandler) ListAccounts(ctx context.Context, params ListAccountsParams) (r ListAccountsRes, _ error)
ListAccounts implements listAccounts operation.
Allows to retrieve a list of accounts based on search parameters.
GET /accounts
Source Files
¶
- oas_cfg_gen.go
- oas_client_gen.go
- oas_handlers_gen.go
- oas_interfaces_gen.go
- oas_json_gen.go
- oas_labeler_gen.go
- oas_middleware_gen.go
- oas_operations_gen.go
- oas_parameters_gen.go
- oas_request_decoders_gen.go
- oas_request_encoders_gen.go
- oas_response_decoders_gen.go
- oas_response_encoders_gen.go
- oas_router_gen.go
- oas_schemas_gen.go
- oas_server_gen.go
- oas_unimplemented_gen.go
- oas_validators_gen.go